<?php

/**
 * @file
 * Contains \Drupal\layout_disable\Form\LayoutDisableForm.
 */

namespace Drupal\layout_disable\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Utility\Html;
use Drupal\Core\Cache\Cache;


/**
 * Administration settings form.
 */
class LayoutDisableForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormID() {
    return 'layout_disable';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('layout_disable.settings');
    $settings = $config->get('layout_disable.settings');

    $layouts = \Drupal::service('plugin.manager.core.layout')->getDefinitions();

    $layout_names = [];
    if (!empty($layouts)) {
      foreach ($layouts as $layoutName => $layoutDefinition) {
        if ($layoutName == 'layout_onecol') {
          // layout_oncecol is required by core and can not be disabled!
          continue;
        }
        $layout_names[Html::escape($layoutName)] = Html::escape($layoutDefinition->getLabel()) . ' (' . Html::escape($layoutDefinition->id()) . ')';
      }
    }

    $form['disabled_layouts'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Disable layouts'),
      '#description' => $this->t('Select the layouts you wish to disable. "layout_oncecol" is required by core and can not be disabled!'),
      '#default_value' => !empty($settings['disabled_layouts']) ? $settings['disabled_layouts'] : [],
      '#options' => $layout_names,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->configFactory->getEditable('layout_disable.settings');
    $form_values = $form_state->getValues();

    $config->set('layout_disable.settings', ['disabled_layouts' => $form_values['disabled_layouts']])
      ->save();
    parent::submitForm($form, $form_state);

    Cache::invalidateTags(['rendered', 'plugin']);
  }
}
